@@ -266,7 +266,7 @@ class Visualize:
                         y=df.values,
                         x=x_loc,
                         name=group,
-                        mode="lines+markers", hover_data=df.index,
+                        mode="lines+markers", text=df.index,
                     )
                 )
 
